@@ -1,3 +1,4 @@
+import os
 from datetime import datetime
 from json import JSONDecodeError
 from os import getenv, makedirs, path
@@ -11,13 +12,19 @@ import subprocess
 import requests
 import logging
 from flask import Flask, request, jsonify
-from flask_api import status
 from flask_script import Manager
-import pyshelf  # must be imported to activate and execute KOs
+
 from kgrid_python_runtime.context import Context
 from kgrid_python_runtime.exceptions import error_handlers
 
 PYSHELF_DIRECTORY = 'pyshelf'
+
+if not path.exists(PYSHELF_DIRECTORY):
+    os.mkdir(PYSHELF_DIRECTORY)
+    print("Created pyshelf directory")
+
+import pyshelf  # must be imported to activate and execute KOs
+
 PYTHON = 'python'
 is_debug_mode = str(getenv('DEBUG', False))
 app_port = getenv('KGRID_PYTHON_ENV_PORT', 5000)
@@ -211,7 +218,7 @@ def activate_from_request(activation_request):
         return ({'baseUrl': python_runtime_url, 'url': endpoint_context.endpoints[hash_key]['url'],
                  "activated": endpoint_context.endpoints[hash_key]['activated'],
                  "status": 'Endpoint is in processing, try again later.', "id": uri, 'uri': hash_key},
-                status.HTTP_503_SERVICE_UNAVAILABLE)
+                503)
     else:
         log.debug(f'processing endpoint: {hash_key}.')
         copy_artifacts_to_shelf(activation_request)
